@@ -22,7 +22,6 @@
 
 import subprocess
 import os
-import datetime
 
 
 def version_tag():
@@ -33,7 +32,7 @@ def version_tag():
     a directory created from the tarball created by setup.py when
     it uses this script and retrieves the original version string
     from that.
-    :return: a version string based on the tag and date
+    :return: a version string based on the tag and short hash
     """
     if not os.path.exists("./.git/"):
         base = os.path.basename(os.getcwd())
@@ -48,38 +47,37 @@ def version_tag():
     ]
     hash_list = ['git', 'log', '-n', '1']
     tag_hash_list = ['git', 'rev-list']
-    clone_data = subprocess.check_output(hash_list).strip()
+    clone_data = subprocess.check_output(hash_list).strip().decode('utf-8')
     commits = clone_data.split('\n')
     clone_hash = commits[0].replace('commit ', '')[:8]
-    tag_data = subprocess.check_output(tag_list).strip()
+    tag_data = subprocess.check_output(tag_list).strip().decode('utf-8')
     tags = tag_data.split('\n')
     if len(tags) < 2:
         return clone_hash
     tag_line = str(tags[len(tags) - 1]).replace('\'', '').strip()
     tag_name = tag_line.split("/")[2]
     tag_hash_list.append(tag_name)
-    tag_hash = subprocess.check_output(tag_hash_list).strip()
+    tag_hash = subprocess.check_output(tag_hash_list).strip().decode('utf-8')
     tags = tag_hash.split('\n')
     tag_hash = tags[0][:8]
     if tag_hash == clone_hash:
         return tag_name
     else:
-        dev_time = datetime.datetime.utcnow()
-        # our tags are one month behind, 04 is tagged in 05
-        # however, the tag is not necessarily made on the first day of 05
-        # so if out by two, allow for an "extended month" to ensure
-        # an incremental version
+        # tag, month end and release are now out of sync.
+        # use the rev-list count to always ensure that we are building
+        # a newer version to cope with date changes at month end.
+        # use short git hash for reference.
         bits = tag_name.split('.')
         tag_month = int(bits[1])
-        extended = dev_time.day
-        if int(dev_time.month) - 1 > tag_month:
-            extended = int(dev_time.day) + 31
-        delayed_tag = "%d.%02d" % (dev_time.year, dev_time.month)
-        return "%s.%02d.%02d" % (tag_name, extended, dev_time.hour)
+        dev_stamp = ['git', 'rev-list', '--count', 'HEAD']
+        dev_count = subprocess.check_output(dev_stamp).strip()
+        dev_short = ['git', 'rev-parse', '--short', 'HEAD']
+        dev_hash = subprocess.check_output(dev_short).strip()
+        return "%s.%s.%s" % (tag_name, dev_count, dev_hash)
 
 
 def main():
-    print version_tag()
+    print(version_tag())
     return 0
 
 if __name__ == '__main__':
